@@ -2,7 +2,7 @@
  *  TwoLAME: an optimized MPEG Audio Layer Two encoder
  *
  *  Copyright (C) 2001-2004 Michael Cheng
- *  Copyright (C) 2004-2006 The TwoLAME Project
+ *  Copyright (C) 2004-2018 The TwoLAME Project
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -18,21 +18,19 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: fft.h 156 2007-03-20 23:57:35Z nhumfrey $
- *
  */
 
 
-#ifndef	_FFT_H_
-#define	_FFT_H_
+#ifndef TWOLAME_FFT_H
+#define TWOLAME_FFT_H
 
 //void fft (FLOAT[BLKSIZE], FLOAT[BLKSIZE], FLOAT[BLKSIZE], FLOAT[BLKSIZE], int);
 
-void psycho_2_fft (FLOAT * x_real, FLOAT * energy, FLOAT * phi);
-void psycho_1_fft (FLOAT * x_real, FLOAT * energy, int N);
+void twolame_psycho_2_fft(FLOAT * x_real, FLOAT * energy, FLOAT * phi);
+void twolame_psycho_1_fft(FLOAT * x_real, FLOAT * energy, int N);
 
 
 #endif
 
 
-// vim:ts=4:sw=4:nowrap: 
+// vim:ts=4:sw=4:nowrap:
