@@ -2,7 +2,7 @@
  *  TwoLAME: an optimized MPEG Audio Layer Two encoder
  *
  *  Copyright (C) 2001-2004 Michael Cheng
- *  Copyright (C) 2004-2006 The TwoLAME Project
+ *  Copyright (C) 2004-2018 The TwoLAME Project
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,6 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: mem.c 156 2007-03-20 23:57:35Z nhumfrey $
- *
  */
 
 
@@ -33,20 +31,17 @@
 *
 *******************************************************************************/
 
-void *twolame_malloc (size_t size, int line, char *file)
+void *twolame_malloc(size_t size, int line, char *file)
 {
-	void *ptr = (void *)malloc(size);
-	
-	if (ptr != NULL) {
-		memset (ptr, 0, size);
-	} else {
-		fprintf (stderr, "Unable to allocate %d bytes at line %d of %s\n", (int)size, line, file);
-		return NULL;
-	}
-	
-	return (ptr);
+    void *ptr = (void *) calloc(size, 1);
+
+    if (ptr == NULL) {
+        fprintf(stderr, "Unable to allocate %d bytes at line %d of %s\n", (int) size, line, file);
+    }
+
+    return (ptr);
 }
 
 
 
-// vim:ts=4:sw=4:nowrap: 
+// vim:ts=4:sw=4:nowrap:
