@@ -2,7 +2,7 @@
  *  TwoLAME: an optimized MPEG Audio Layer Two encoder
  *
  *  Copyright (C) 2001-2004 Michael Cheng
- *  Copyright (C) 2004-2006 The TwoLAME Project
+ *  Copyright (C) 2004-2018 The TwoLAME Project
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -18,12 +18,10 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: mem.h 156 2007-03-20 23:57:35Z nhumfrey $
- *
  */
 
-#ifndef _MEM_H
-#define _MEM_H
+#ifndef TWOLAME_MEM_H
+#define TWOLAME_MEM_H
 
 
 #include "common.h"
@@ -46,9 +44,9 @@
 #define TWOLAME_FREE(ptr) if(ptr!=NULL) { free(ptr); ptr=NULL; }
 
 // Functions
-void *twolame_malloc (size_t size, int line,  char *file);
+void *twolame_malloc(size_t size, int line, char *file);
 
 #endif
 
 
-// vim:ts=4:sw=4:nowrap: 
+// vim:ts=4:sw=4:nowrap:
